@@ -1,15 +1,15 @@
 """Card notification hooks
 
 :organization: Logilab
-:copyright: 2003-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.sobjects.notification import ContentAddedView
 
 class CardAddedView(ContentAddedView):
     """get notified from new cards"""
-    __select__ = implements('Card')
+    __select__ = is_instance('Card')
     content_attr = 'synopsis'
