@@ -3,24 +3,23 @@
 Specific views for cards
 
 :organization: Logilab
-:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2001-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from logilab.mtconverter import html_escape
-
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web import uicfg
 from cubicweb.web.views import primary
+from cubicweb.web.views.autoform import AutomaticEntityForm
 
 uicfg.primaryview_section.tag_attribute(('Card', 'title'), 'hidden')
 uicfg.primaryview_section.tag_attribute(('Card', 'synopsis'), 'hidden')
 uicfg.primaryview_section.tag_attribute(('Card', 'wikiid'), 'hidden')
 
 class CardPrimaryView(primary.PrimaryView):
-    __select__ = implements('Card')
+    __select__ = is_instance('Card')
     show_attr_label = False
 
     def summary(self, entity):
@@ -38,3 +37,20 @@ class CardInlinedView(CardPrimaryView):
 
     def render_entity_metadata(self, entity):
         pass
+
+    def content_navigation_components(self, context):
+        pass
+
+
+def registration_callback(vreg):
+    vreg.register(CardPrimaryView)
+    vreg.register(CardInlinedView)
+    if 'preview' in vreg.config.cubes():
+
+        from cubes.preview.views.forms import PreviewFormMixin
+        class PreviewAutomaticEntityForm(PreviewFormMixin, AutomaticEntityForm):
+            preview_mode = 'inline'
+            __select__ = AutomaticEntityForm.__select__ & is_instance('Card')
+
+        vreg.register(PreviewAutomaticEntityForm)
+
